#
# spec file for package python-wptools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pyname wptools
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-wptools
Version:        0.4.12
Release:        lp150.1.1
Summary:        Wikipedia tools (for Humans)
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/siznax/wptools/
Source:         https://files.pythonhosted.org/packages/source/w/wptools/%{pyname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM python-wptools-avoid-reading-readme.patch badshah400@gmail.com -- README.rst contains numerous spurious characters that are not readable in ascii. Skip reading this file in setup.py and manually insert a long description text instead
Patch0:         python-wptools-avoid-reading-readme.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-unittest2
Requires:       python-certifi >= 2017.7.27.1
Requires:       python-html2text >= 2016.9.19
Requires:       python-lxml >= 3.8.0
Requires:       python-pycurl >= 7.43.0
BuildArch:      noarch
%python_subpackages

%description
Python and command-line MediaWiki access for Humans.

Features:
* get an HTML or plain text "extract" (lead or summary)
* get a representative image (pageimage, thumb, etc.)
* get an Infobox as a python dictionary
* get any/all Wikidata by title
* get info in any language
* get random info

%prep
%setup -q -n wptools-%{version}
%patch0 -p1
sed -i '1d' scripts/wptool.py

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
# TESTS ONLY WORK WITH PY3 UNITTEST
%ifpython3
%python_exec setup.py test
%endif

%files %{python_files}
%doc HISTORY.rst LICENSE README.rst
%python3_only %{_bindir}/wptool
%{python_sitelib}/*

%changelog
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 0.4.12 [list of changes cumulated from version
  0.4.9]:
  * Respect silence (gh#siznax/wptools#118).
  * Added more general infobox parsing alternative.
  * Improved infobox parsing.
* Fri Jan 26 2018 badshah400@gmail.com
- Update to version 0.4.7:
  * Fixed Wikidata pageid, image bugs and added Commons image
    metadata.
* Sun Jan 14 2018 badshah400@gmail.com
- Update to version 0.4.7:
  * Added support for non-value Wikidata snaktypes, and category
    continuations.
- Rebase python-wptools-avoid-reading-readme.patch.
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 0.4.6:
  * Merged deleted Wikidata item PR (gh#siznax/wptools#97).
- Rebase python-wptools-avoid-reading-readme.patch to apply
  cleanly against updated sources.
* Tue Dec 19 2017 badshah400@gmail.com
- Update to version 0.4.5:
  * Fixed TypeError on Windows 10 (gh#siznax/wptools#95)
  * Fixed RESTBase LookupError on slash titles
    (gh#siznax/wptools#94)
  * Added boxterm param for more Infobox reach
    (gh#siznax/wptools#91)
  * Improved stress tests, wptool CLI script output
  * Fixed get_imageinfo() issue (gh#siznax/wptools#93)
  * Getting ALL Wikidata (gh#siznax/wptools#56)
  * Surfaced redirects, disambiguation links
    (gh#siznax/wptools#25)
  * Increased test coverage to 95%%, pylint score 10.0
  * Added more page data, split off expensive queries
  * Implemented basic category and site functionality
  * Changed page._WIKIPROPS to wikidata.LABELS
  * Refactored attributes to only cache, data, flags, params
  * Unified Wikimedia APIs access pattern via wptools.core
- Rebase python-wptools-avoid-reading-readme.patch to apply
  cleanly against updated sources.
- Run tests (BuildRequires: python3-unittest2); this only works
  with py3 unittest module, so only enable tests conditionally.
* Wed Oct 25 2017 aloisio@gmx.com
- Update to version 0.4
- Converted to single-spec
- Refreshed python3-wptools-avoid-reading-readme.patch as
  python-wptools-avoid-reading-readme.patch
* Tue Mar 14 2017 badshah400@gmail.com
- Initial package.
- Add python3-wptools-avoid-reading-readme.patch: README.rst
  contains numerous spurious characters that are not readable in
  ascii, causing setup.py to fail. Skip reading this file in
  setup.py and manually insert a long description text instead.
